@@ -31,7 +31,7 @@
 #ifndef __IOADEFS__
 #define __IOADEFS__
 
-#define TURN_SERVER_VERSION "4.4.2.1"
+#define TURN_SERVER_VERSION "4.4.4.2"
 #define TURN_SERVER_VERSION_NAME "Ardee West"
 #define TURN_SOFTWARE "Coturn-" TURN_SERVER_VERSION " '" TURN_SERVER_VERSION_NAME "'"
 
@@ -218,6 +218,30 @@ typedef u32bits turn_time_t;
 
 ////////////////////////////////////////////////////////
 
+#define CLIENT_DGRAM_SOCKET_TYPE SOCK_DGRAM
+#define CLIENT_DGRAM_SOCKET_PROTOCOL IPPROTO_IP
+
+#define CLIENT_STREAM_SOCKET_TYPE SOCK_STREAM
+#define CLIENT_STREAM_SOCKET_PROTOCOL IPPROTO_IP
+
+#define SCTP_CLIENT_STREAM_SOCKET_TYPE SOCK_STREAM
+
+#if !defined(TURN_NO_SCTP)
+#define SCTP_CLIENT_STREAM_SOCKET_PROTOCOL IPPROTO_SCTP
+#else
+#define SCTP_CLIENT_STREAM_SOCKET_PROTOCOL IPPROTO_IP
+#endif
+
+#define RELAY_DGRAM_SOCKET_TYPE SOCK_DGRAM
+#define RELAY_DGRAM_SOCKET_PROTOCOL IPPROTO_IP
+#define RELAY_STREAM_SOCKET_TYPE SOCK_STREAM
+#define RELAY_STREAM_SOCKET_PROTOCOL IPPROTO_IP
+
+#define ADMIN_STREAM_SOCKET_TYPE SOCK_STREAM
+#define ADMIN_STREAM_SOCKET_PROTOCOL IPPROTO_IP
+
+////////////////////////////////////////////////////////
+
 #ifdef __cplusplus
 }
 #endif
